
import { DateTime } from 'luxon';

export function now(zone?: string) {
	return zone
		? DateTime.now().setZone(zone)
		: DateTime.now();
}

export function from_iso(time: string, zone?: string) {
	return zone
		? DateTime.fromISO(time, { zone })
		: DateTime.fromISO(time);
}

export function as_html_time(time: DateTime, classname = '', lang?: string, config?: Intl.DateTimeFormatOptions) {
	if (lang && config) {
		const formatter = new Intl.DateTimeFormat(lang, config);
		const formatted = formatter.format(new Date(time.toISO()));
		return `<time datetime="${time.toISO()}">${formatted}</time>`;
	}

	return `<time class="${classname}" datetime="${time.toISO()}">${time.toRFC2822()}</time>`;
}

export function as_context_time(time: DateTime, classname = '', lang?: string, config?: Intl.DateTimeFormatOptions) {
	return {
		iso: time.toISO(),
		rfc2822: time.toRFC2822(),
		html: as_html_time(time, classname, lang, config),
	};
}
